==> certmanager-model-v1alpha3-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ChallengeFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ChallengeFluentImpl<A extends ChallengeFluent<A>> extends BaseFluent<A> implements ChallengeFluent<A>{
  public ChallengeFluentImpl() {
  }
  public ChallengeFluentImpl(Challenge instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ChallengeSpecBuilder spec;
  private ChallengeStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ChallengeFluent.MetadataNested<A> withNewMetadata() {
    return new ChallengeFluentImpl.MetadataNestedImpl();
  }
  public ChallengeFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ChallengeFluentImpl.MetadataNestedImpl(item);
  }
  public ChallengeFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ChallengeFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ChallengeFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ChallengeSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ChallengeSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ChallengeSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ChallengeSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ChallengeFluent.SpecNested<A> withNewSpec() {
    return new ChallengeFluentImpl.SpecNestedImpl();
  }
  public ChallengeFluent.SpecNested<A> withNewSpecLike(ChallengeSpec item) {
    return new ChallengeFluentImpl.SpecNestedImpl(item);
  }
  public ChallengeFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ChallengeFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ChallengeSpecBuilder().build());
  }
  public ChallengeFluent.SpecNested<A> editOrNewSpecLike(ChallengeSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ChallengeStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ChallengeStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ChallengeStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ChallengeStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean presented,Boolean processing,String reason,String state) {
    return (A)withStatus(new ChallengeStatus(presented, processing, reason, state));
  }
  public ChallengeFluent.StatusNested<A> withNewStatus() {
    return new ChallengeFluentImpl.StatusNestedImpl();
  }
  public ChallengeFluent.StatusNested<A> withNewStatusLike(ChallengeStatus item) {
    return new ChallengeFluentImpl.StatusNestedImpl(item);
  }
  public ChallengeFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ChallengeFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ChallengeStatusBuilder().build());
  }
  public ChallengeFluent.StatusNested<A> editOrNewStatusLike(ChallengeStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ChallengeFluentImpl that = (ChallengeFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ChallengeFluent.MetadataNested<N>> implements ChallengeFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ChallengeFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ChallengeSpecFluentImpl<ChallengeFluent.SpecNested<N>> implements ChallengeFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ChallengeSpec item) {
      this.builder = new ChallengeSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ChallengeSpecBuilder(this);
    }
    ChallengeSpecBuilder builder;
    public N and() {
      return (N) ChallengeFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ChallengeStatusFluentImpl<ChallengeFluent.StatusNested<N>> implements ChallengeFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ChallengeStatus item) {
      this.builder = new ChallengeStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ChallengeStatusBuilder(this);
    }
    ChallengeStatusBuilder builder;
    public N and() {
      return (N) ChallengeFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ChallengeFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ChallengeFluentImpl<A extends ChallengeFluent<A>> extends BaseFluent<A> implements ChallengeFluent<A>{
  public ChallengeFluentImpl() {
  }
  public ChallengeFluentImpl(Challenge instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ChallengeSpecBuilder spec;
  private ChallengeStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ChallengeFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ChallengeFluentImpl.MetadataNestedImpl();
  }
  public ChallengeFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ChallengeFluentImpl.MetadataNestedImpl(item);
  }
  public ChallengeFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ChallengeFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ChallengeFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ChallengeSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ChallengeSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ChallengeSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ChallengeSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ChallengeFluentImpl.SpecNested<A> withNewSpec() {
    return new ChallengeFluentImpl.SpecNestedImpl();
  }
  public ChallengeFluentImpl.SpecNested<A> withNewSpecLike(ChallengeSpec item) {
    return new ChallengeFluentImpl.SpecNestedImpl(item);
  }
  public ChallengeFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ChallengeFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ChallengeSpecBuilder().build());
  }
  public ChallengeFluentImpl.SpecNested<A> editOrNewSpecLike(ChallengeSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ChallengeStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ChallengeStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ChallengeStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ChallengeStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean presented,Boolean processing,String reason,String state) {
    return (A)withStatus(new ChallengeStatus(presented, processing, reason, state));
  }
  public ChallengeFluentImpl.StatusNested<A> withNewStatus() {
    return new ChallengeFluentImpl.StatusNestedImpl();
  }
  public ChallengeFluentImpl.StatusNested<A> withNewStatusLike(ChallengeStatus item) {
    return new ChallengeFluentImpl.StatusNestedImpl(item);
  }
  public ChallengeFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ChallengeFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ChallengeStatusBuilder().build());
  }
  public ChallengeFluentImpl.StatusNested<A> editOrNewStatusLike(ChallengeStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ChallengeFluentImpl that = (ChallengeFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ChallengeFluentImpl.MetadataNested<N>> implements ChallengeFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ChallengeFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ChallengeSpecFluentImpl<ChallengeFluentImpl.SpecNested<N>> implements ChallengeFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ChallengeSpec item) {
      this.builder = new ChallengeSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ChallengeSpecBuilder(this);
    }
    ChallengeSpecBuilder builder;
    public N and() {
      return (N) ChallengeFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ChallengeStatusFluentImpl<ChallengeFluentImpl.StatusNested<N>> implements ChallengeFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ChallengeStatus item) {
      this.builder = new ChallengeStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ChallengeStatusBuilder(this);
    }
    ChallengeStatusBuilder builder;
    public N and() {
      return (N) ChallengeFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
